==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cy/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Cadarnahu Dileu Nifer o Asedau',
  'bulk_delete_help'	=> 'Adolygwch yr asedau ar gyfer dileu isod. Ar ôl eu dileu, gellir adfer yr asedau hyn, ond ni fyddant yn gysylltiedig mwyach ag unrhyw ddefnyddwyr y maent wedi\'u neilltuo iddynt ar hyn o bryd.',
  'bulk_delete_warn'	=> 'Rydych am dileu :asset_count assets.',
	'bulk_update'		=> 'Diweddaru Nifer o Asedau',
	'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o asedau ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath. ',
	'bulk_update_warn'	=> 'Rydych am newid manylder am :asset_count o asedau.',
    'checkedout_to'		=> 'Wedi aseinio i',
    'checkout_date'		=> 'Dyddiad allan',
    'checkin_date'		=> 'Dyddian i mewn',
    'checkout_to'		=> 'Dynodi i',
    'cost'				=> 'Cost pwrcasu',
    'create'			=> 'Creu Ased',
    'date'				=> 'Dyddiad Pwrcasu',
    'depreciation'	    => 'Dibrisiant',
    'depreciates_on'	=> 'Dibrisio Ar',
    'default_location'	=> 'Lleoliad diofyn',
    'eol_date'			=> 'Dyddiad DB',
    'eol_rate'			=> 'Cyfradd DB',
    'expected_checkin'  => 'Dyddiad disgwl i mewn',
    'expires'			=> 'Dod i ben',
    'fully_depreciated'	=> 'Dibrisiant Llwyr',
    'help_checkout'		=> 'Os ydych chi am aseinio\'r ased hwn ar unwaith, dewiswch "Barod i\'w Ddefnyddio" o\'r rhestr statws uchod. ',
    'mac_address'		=> 'Cyfeiriad MAC',
    'manufacturer'		=> 'Gwneuthyrwr',
    'model'				=> 'Model',
    'months'			=> 'misoedd',
    'name'				=> 'Enw Ased',
    'notes'				=> 'Nodiadau',
    'order'				=> 'Rhif Archeb',
    'qr'				=> 'Côd QR',
    'requestable'		=> 'Gellir ddefnyddwyr gwneud cais am yr ased yma',
    'select_statustype'	=> 'Dewis Math o Statws',
    'serial'			=> 'Serial',
    'status'			=> 'Statws',
    'tag'				=> 'Tag Ased',
    'update'			=> 'Diweddaru Ased',
    'warranty'			=> 'Warant',
		'warranty_expires'		=> 'Warrant yn dod I ben',
    'years'				=> 'blynyddoedd',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cy/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Cadarnahu Dileu Nifer o Asedau',
  'bulk_delete_help'	=> 'Adolygwch yr asedau ar gyfer dileu isod. Ar ôl eu dileu, gellir adfer yr asedau hyn, ond ni fyddant yn gysylltiedig mwyach ag unrhyw ddefnyddwyr y maent wedi\'u neilltuo iddynt ar hyn o bryd.',
  'bulk_delete_warn'	=> 'Rydych am dileu :asset_count assets.',
    'bulk_update'		=> 'Diweddaru Nifer o Asedau',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o asedau ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath. ',
    'bulk_update_warn'	=> 'Rydych am newid manylder am :asset_count o asedau.',
    'checkedout_to'		=> 'Wedi aseinio i',
    'checkout_date'		=> 'Dyddiad allan',
    'checkin_date'		=> 'Dyddian i mewn',
    'checkout_to'		=> 'Dynodi i',
    'cost'				=> 'Cost pwrcasu',
    'create'			=> 'Creu Ased',
    'date'				=> 'Dyddiad Pwrcasu',
    'depreciation'	    => 'Dibrisiant',
    'depreciates_on'	=> 'Dibrisio Ar',
    'default_location'	=> 'Lleoliad diofyn',
    'eol_date'			=> 'Dyddiad DB',
    'eol_rate'			=> 'Cyfradd DB',
    'expected_checkin'  => 'Dyddiad disgwl i mewn',
    'expires'			=> 'Dod i ben',
    'fully_depreciated'	=> 'Dibrisiant Llwyr',
    'help_checkout'		=> 'Os ydych chi am aseinio\'r ased hwn ar unwaith, dewiswch "Barod i\'w Ddefnyddio" o\'r rhestr statws uchod. ',
    'mac_address'		=> 'Cyfeiriad MAC',
    'manufacturer'		=> 'Gwneuthyrwr',
    'model'				=> 'Model',
    'months'			=> 'misoedd',
    'name'				=> 'Enw Ased',
    'notes'				=> 'Nodiadau',
    'order'				=> 'Rhif Archeb',
    'qr'				=> 'Côd QR',
    'requestable'		=> 'Gellir ddefnyddwyr gwneud cais am yr ased yma',
    'select_statustype'	=> 'Dewis Math o Statws',
    'serial'			=> 'Serial',
    'status'			=> 'Statws',
    'tag'				=> 'Tag Ased',
    'update'			=> 'Diweddaru Ased',
    'warranty'			=> 'Warant',
        'warranty_expires'		=> 'Warrant yn dod I ben',
    'years'				=> 'blynyddoedd',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
